@@ -1,6 +1,7 @@
 # ruff: noqa: RUF009
 from dataclasses import dataclass
-from typing import List, Optional
+from enum import IntFlag
+from typing import Iterable, List, Literal, Optional, Union
 
 from robotcode.robot.config.model import BaseOptions, field
 from robotcode.robot.diagnostics.workspace_config import (
@@ -197,10 +198,74 @@ class CacheConfig(BaseOptions):
     )
 
 
+class ExitCodeMask(IntFlag):
+    NONE = 0
+    ERROR = 1
+    WARN = 2
+    WARNING = WARN
+    INFO = 4
+    INFORMATION = INFO
+    HINT = 8
+    ALL = ERROR | WARN | INFO | HINT
+
+    @staticmethod
+    def parse(value: Union[Iterable[str], str, None]) -> "ExitCodeMask":
+        if value is None:
+            return ExitCodeMask.NONE
+
+        flags = ExitCodeMask(0)
+        for entry in value:
+            for part_orig in entry.split(","):
+                part = part_orig.strip().upper()
+                if part:
+                    try:
+                        flags |= ExitCodeMask[part]
+                    except KeyError as e:
+                        raise KeyError(f"Invalid exit code mask value: {part_orig}") from e
+        return flags
+
+
+ExitCodeMaskLiteral = Literal["error", "warn", "warning", "info", "information", "hint", "all"]
+ExitCodeMaskList = List[ExitCodeMaskLiteral]
+
+
+@dataclass
+class CodeConfig(BaseOptions):
+    """robotcode-analyze code configuration."""
+
+    exit_code_mask: Optional[ExitCodeMaskList] = field(
+        description="""\
+            Specifies the exit code mask for the code analysis.
+            This is useful if you want to ignore certain types of diagnostics in the result code.
+
+            Examples:
+            ```toml
+            [tool.robotcode-analyze.code]
+            exit_code_mask = ["error", "warn"]
+            ```
+            """,
+    )
+    extend_exit_code_mask: Optional[ExitCodeMaskList] = field(description="Extend the exit code mask setting.")
+
+
 @dataclass
 class AnalyzeConfig(BaseOptions):
     """robotcode-analyze configuration."""
 
+    code: Optional[CodeConfig] = field(
+        description="""\
+            Defines the code analysis configuration.
+
+            Examples:
+
+            ```toml
+            [tool.robotcode-analyze.code]
+            exit_code_mask = "error|warn"
+            ```
+        """
+    )
+    extend_code: Optional[CodeConfig] = field(description="Extend the code analysis configuration.")
+
     modifiers: Optional[ModifiersConfig] = field(
         description="""\
             Defines the modifiers for the analysis.
@@ -253,6 +318,37 @@ class AnalyzeConfig(BaseOptions):
         description="Extend the global library search order setting."
     )
 
+    load_library_timeout: Optional[int] = field(
+        description="""\
+            Specifies the timeout in seconds for loading (importing) libraries and variable files during
+            analysis. Increase this if your libraries perform heavy initialization (network calls, large
+            dependency graphs, model loading, etc.).
+
+            Must be > 0 when set. If you omit this key, RobotCode will instead look for the environment
+            variable `ROBOTCODE_LOAD_LIBRARY_TIMEOUT`; otherwise it will use the internal default `10`.
+
+            Examples:
+
+            ```toml
+            [tool.robotcode-analyze]
+            # Fast fail if libraries normally import in < 2s
+            load_library_timeout = 5
+            ```
+
+            ```toml
+            [tool.robotcode-analyze]
+            # Allow heavy bootstrap (e.g. Selenium + large resource trees)
+            load_library_timeout = 30
+            ```
+
+            ```toml
+            [tool.robotcode-analyze]
+            # Omit to use default
+            # load_library_timeout = 15
+            ```
+        """,
+    )
+
     def to_workspace_analysis_config(self) -> WorkspaceAnalysisConfig:
         return WorkspaceAnalysisConfig(
             exclude_patterns=self.exclude_patterns or [],
@@ -266,7 +362,10 @@ class AnalyzeConfig(BaseOptions):
                 if self.cache is not None
                 else WorkspaceCacheConfig()
             ),
-            robot=AnalysisRobotConfig(global_library_search_order=self.global_library_search_order or []),
+            robot=AnalysisRobotConfig(
+                global_library_search_order=self.global_library_search_order or [],
+                load_library_timeout=self.load_library_timeout,
+            ),
             modifiers=(
                 AnalysisDiagnosticModifiersConfig(
                     ignore=self.modifiers.ignore or [],
